# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support
%bcond_with jdk6
%bcond_without signed

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define archivever 143

%define section free

Name:           bouncycastle
Version:        1.43
Release:        1%{?dist}
Epoch:          0
Summary:        Bouncy Castle Crypto Package for Java
Group:          Security/Cryptography
License:        BSD
URL:            http://www.bouncycastle.org/java.html
Source0:        http://downloads.bouncycastle.org/java/crypto-%{archivever}.tar.gz
Source1:        http://downloads.bouncycastle.org/java/bcprov-jdk15-%{archivever}.jar
Source2:        http://downloads.bouncycastle.org/java/bcprov-jdk16-%{archivever}.jar
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  geronimo-jaf-1.0.2-api
BuildRequires:  geronimo-javamail-1.4-api
BuildRequires:  junit
BuildRequires:  java-devel >= 0:1.5
BuildRequires:  jpackage-utils
%if %{gcj_support}
BuildRequires:  java-gcj-compat-devel
%else
BuildArch:      noarch
%endif # gcj_support
# BEGIN PROVIDER
Requires:       geronimo-jaf-1.0.2-api
Requires:       geronimo-javamail-1.4-api
Obsoletes:      %{name}-provider < %{epoch}:%{version}-%{release}
Provides:       %{name}-provider = %{epoch}:%{version}-%{release}
%if %with jdk6
Provides:       jce = 0:1.6.0.0
%else
Provides:       jce = 0:1.5.0.0
%endif
# END PROVIDER
Obsoletes:      bouncycastle-jdk1.4 < %{epoch}:%{version}-%{release}
Obsoletes:      bouncycastle-jdk1.5 < %{epoch}:%{version}-%{release}
Obsoletes:      bouncycastle-jdk1.6 < %{epoch}:%{version}-%{release}
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description

The Bouncy Castle Crypto APIs for Java consist of the following:

    * A lightweight cryptography API for Java.

    * A provider for the Java Cryptography Extension and the Java Cryptography Architecture.

    * A clean room implementation of the JCE 1.2.1.

    * A library for reading and writing encoded ASN.1 objects.

    * A light weight client-side TLS API.

    * Generators for Version 1 and Version 3 X.509 certificates, Version 2 CRLs, and PKCS12 files.

    * Generators for Version 2 X.509 attribute certificates.

    * Generators/Processors for S/MIME and CMS (PKCS7/RFC 3852).

    * Generators/Processors for OCSP (RFC 2560).

    * Generators/Processors for TSP (RFC 3161).

    * Generators/Processors for OpenPGP (RFC 2440).
%if %without jdk6
    * A signed jar version suitable for JDK 1.5 and the Sun JCE.
%else
    * A signed jar version suitable for JDK 1.6 and the Sun JCE.
%endif
The lightweight API works with everything from the J2ME to the JDK 1.6.

%package javadoc
Group:          Documentation
Summary:        Javadoc for %{name}
Obsoletes:      bouncycastle-javadoc-jdk1.4 < %{epoch}:%{version}-%{release}
Obsoletes:      bouncycastle-javadoc-jdk1.5 < %{epoch}:%{version}-%{release}
Obsoletes:      bouncycastle-javadoc-jdk1.6 < %{epoch}:%{version}-%{release}

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n crypto-%{archivever}
%{_bindir}/find . -name '*.jar' | %{_bindir}/xargs -t %{__rm}

%build
export CLASSPATH=$(build-classpath jaf javamail_1_4_api junit)
export OPT_JAR_LIST="`%{__cat} %{_sysconfdir}/ant.d/junit`"
%if %with jdk6
%{ant} -f jdk16.xml -Drelease.suffix=%{version} build-provider build build-test
%else
%{ant} -f jdk15.xml -Drelease.suffix=%{version} build-provider build build-test
%endif

%install
%{__rm} -rf %{buildroot}

%{__mkdir_p} %{buildroot}%{_javadir}

%if %with jdk6
pushd build/artifacts/jdk1.6/jars
for jar16 in {bcmail,bcpg,bcprov,bctest,bctsp}-jdk16-%{version}.jar; do
   jar16d=`echo $jar16 | %{__sed} s/-jdk16//g`
   %{__install} -p -m 644 $jar16 %{buildroot}%{_javadir}/$jar16d
done
popd
%else
pushd build/artifacts/jdk1.5/jars
for jar15 in {bcmail,bcpg,bcprov,bctest,bctsp}-jdk15-%{version}.jar; do
   jar15d=`echo $jar15 | %{__sed} s/-jdk15//g`
   %{__install} -p -m 644 $jar15 %{buildroot}%{_javadir}/$jar15d
done
popd
%endif

%if %with signed
%if %without jdk6
%{__install} -p -m 644 %{SOURCE1} %{buildroot}%{_javadir}/bcprov-%{version}.jar
%else
%{__install} -p -m 644 %{SOURCE2} %{buildroot}%{_javadir}/bcprov-%{version}.jar
%endif
%endif

pushd %{buildroot}%{_javadir}
  for jar in *-%{version}.jar; do
    %{__ln_s} $jar $(echo $jar | %{__sed} s/-%{version}//g)
  done
popd

%{__mkdir_p} %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__ln_s} %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}

%if %with jdk6
pushd build/artifacts/jdk1.6
  ver=16
  for javadoc in bcmail bcpg bcprov bctsp; do
    %{__mkdir_p} %{buildroot}%{_javadocdir}/%{name}-%{version}/${javadoc}
    %{__cp} -pr ${javadoc}-jdk${ver}-%{version}/docs/* %{buildroot}%{_javadocdir}/%{name}-%{version}/${javadoc}
  done
popd
%else
pushd build/artifacts/jdk1.5
  ver=15
  for javadoc in bcmail bcpg bcprov bctsp; do
    %{__mkdir_p} %{buildroot}%{_javadocdir}/%{name}-%{version}/${javadoc}
    %{__cp} -pr ${javadoc}-jdk${ver}-%{version}/docs/* %{buildroot}%{_javadocdir}/%{name}-%{version}/${javadoc}
  done
popd
%endif

%if %{gcj_support}
%{__mkdir_p} %{buildroot}%{_javadir}/gcj-endorsed
(cd %{buildroot}%{_javadir}/gcj-endorsed && %{__ln_s} %{_javadir}/bcprov.jar bcprov.jar)
%endif # gcj_support

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif # gcj_support

%clean
%{__rm} -rf %{buildroot}

%if %{gcj_support}
%post
if [ -x %{_bindir}/rebuild-security-providers ]; then
  %{_bindir}/rebuild-security-providers
fi
if [ -x %{_bindir}/rebuild-gcj-db ]; then
  %{_bindir}/rebuild-gcj-db
fi

%postun
if [ -x %{_bindir}/rebuild-security-providers ]; then
  %{_bindir}/rebuild-security-providers
fi
if [ -x %{_bindir}/rebuild-gcj-db ]; then
  %{_bindir}/rebuild-gcj-db
fi
%endif # gcj_support

%files
%defattr(0644,root,root,0755)
%doc *.html
# BEGIN PROVIDER
%{_javadir}/bcmail-%{version}.jar
%{_javadir}/bcpg-%{version}.jar
%{_javadir}/bctest-%{version}.jar
%{_javadir}/bctest.jar
%{_javadir}/bctsp-%{version}.jar
%{_javadir}/bcmail.jar
%{_javadir}/bcpg.jar
%{_javadir}/bctsp.jar
%{_javadir}/bcprov-%{version}.jar
%{_javadir}/bcprov.jar
%if %{gcj_support}
%{_javadir}/gcj-endorsed/bcprov.jar
%dir %{_libdir}/gcj/%{name}
%{_libdir}/gcj/%{name}/bcprov-%{version}.jar.so
%{_libdir}/gcj/%{name}/bcprov-%{version}.jar.db
%{_libdir}/gcj/%{name}/bcmail-%{version}.jar.so
%{_libdir}/gcj/%{name}/bcmail-%{version}.jar.db
%{_libdir}/gcj/%{name}/bcpg-%{version}.jar.so
%{_libdir}/gcj/%{name}/bcpg-%{version}.jar.db
%{_libdir}/gcj/%{name}/bctest-%{version}.jar.db
%{_libdir}/gcj/%{name}/bctest-%{version}.jar.so
%{_libdir}/gcj/%{name}/bctsp-%{version}.jar.so
%{_libdir}/gcj/%{name}/bctsp-%{version}.jar.db
%endif
# END PROVIDER

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%changelog
* Mon Apr 20 2009 David Walluck <dwalluck@redhat.com> 0:1.43-1
- 1.43

* Fri Mar 20 2009 David Walluck <dwalluck@redhat.com> 0:1.42-3
- package using the upstream signed jars by default

* Tue Mar 17 2009 David Walluck <dwalluck@redhat.com> 0:1.42-2
- add support for upstream-signed jar
- update URL and description

* Mon Mar 16 2009 David Walluck <dwalluck@redhat.com> 0:1.42-1
- 1.42
- add support for jdk5

* Mon Dec 08 2008 Will Tatam <will.tatam@red61.com> 0:1.41-2
- Auto rebuild for JPackage 5 in mock

* Thu Nov 13 2008 David Walluck <dwalluck@redhat.com> 0:1.41-1
- 1.41
- require javamail 1.4

* Thu Nov 01 2007 Ralph Apel <r.apel at r-apel.de> 0:1.37-5jpp
- Bump release

* Tue Oct 31 2007 Ralph Apel <r.apel at r-apel.de> 0:1.37-4jpp
- Explicitly Require bouncycastle-jdk1.5 in main package

* Tue Oct 30 2007 Ralph Apel <r.apel at r-apel.de> 0:1.37-3jpp
- Build jdk1.4 thru jdk1.6 packages for JPP-5.0

* Tue Oct 30 2007 Ralph Apel <r.apel at r-apel.de> 0:1.37-2jpp
- Build jdk1.4 packages for JPP-1.7

* Wed Jul 11 2007 Ralph Apel <r.apel at r-apel.de> 0:1.37-1jpp
- Upgrade to 1.37
- Add bctsp
- Add more original (i.e. signed) jars
- Require java, java-devel < 1.6.0

* Mon Feb 21 2005 David Walluck <david@jpackage.org> 0:1.27-1jpp
- 1.27
- "fix" requires-on-release
- change license to BSD (style)
- fix duplicate requires

* Thu Jan 20 2005 David Walluck <david@jpackage.org> 0:1.26-1jpp
- 1.26

* Sat Oct 09 2004 David Walluck <david@jpackage.org> 0:1.25-1jpp
- 1.25
- jdk 1.3.x support out, jdk 1.5.0 support in

* Sun Feb 08 2004 David Walluck <david@anti-microsoft.org> 0:1.25-1jpp
- 1.25
- fix javadocs and javadoc dirs
- clean up BuildRequires/Requires
- CLASSPATH doesn't need jce

* Tue Jan 20 2004 David Walluck <david@anti-microsoft.org> 0:1.21-1jpp
- 1.21

* Fri Oct 10 2003 David Walluck <david@anti-microsoft.org> 0:1.20-2jpp
- fix javadoc symlinks

* Fri Oct 10 2003 David Walluck <david@anti-microsoft.org> 0:1.20-1jpp
- 1.20
- add epochs
- %%ghost symlinks
- maybe bouncycastle should consider using ant so that it
  doesn't take over three hours to script the build process
- oh, and maybe a single source archive, thanks

* Sun Sep 09 2003 David Walluck <david@anti-microsoft.org> 0:1.19-2jpp 
- build bcmail.jar for jdk1.4 package
- add Epoch
- Requires: jpackage-utils >= 0:1.5

* Fri Jun 27 2003 Nicolas Mailhot <Nicolas.Mailhot at laPoste.net> 1.19-1jpp
- First jpackage 1.5 release
- use upstream 1.4 binary due to Sun braindamage

* Sun Sep  8 2002 Ville Skyttä <ville.skytta at iki.fi> 1.15-1jpp
- First JPackage release.
